@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2017-2020 Richard Hull and contributors
+# Copyright (c) 2017-2021 Richard Hull and contributors
 # See LICENSE.rst for details.
 
 """
@@ -49,7 +49,6 @@ class i2c(object):
           that it has already been opened.
     """
     def __init__(self, bus=None, port=1, address=0x3C):
-        import smbus2
         self._cmd_mode = 0x00
         self._data_mode = 0x40
 
@@ -60,9 +59,16 @@ class i2c(object):
                 f'I2C device address invalid: {address}')
 
         try:
-            self._managed = bus is None
-            self._i2c_msg_write = smbus2.i2c_msg.write if bus is None else None
-            self._bus = bus or smbus2.SMBus(port)
+            if bus is None:
+                import smbus2
+
+                self._managed = True
+                self._i2c_msg_write = smbus2.i2c_msg.write
+                self._bus = smbus2.SMBus(port)
+            else:
+                self._managed = False
+                self._i2c_msg_write = None
+                self._bus = bus
         except (IOError, OSError) as e:
             if e.errno == errno.ENOENT:
                 # FileNotFoundError
@@ -250,7 +256,7 @@ class bitbang(object):
         Clean up GPIO resources if managed.
         """
         if self._managed:
-            self._gpio.cleanup()
+            self._gpio.cleanup([pin for pin in [self._SCLK, self._SDA, self._CE, self._DC, self._RST] if pin is not None])
 
 
 @lib.spidev
@@ -359,6 +365,14 @@ class gpio_cs_spi(spi):
         if self._gpio_CS:
             self._gpio.output(self._gpio_CS, self._gpio.LOW if self._cs_high else self._gpio.HIGH)
 
+    def cleanup(self):
+        """
+        Close pin if it was set up.
+        """
+        if self._gpio_CS is not None:
+            self._gpio.cleanup(self._gpio_CS)
+        super(gpio_cs_spi, self).cleanup()
+
 
 class noop(object):
     """
@@ -418,7 +432,7 @@ class __FTDI_WRAPPER_GPIO:
 
         self._gpio.write(self._data)
 
-    def cleanup(self):
+    def cleanup(self, pin):
         pass
 
 
